@@ -645,7 +645,9 @@ int main(int argc,char **argv)
 			fprintf(stderr, " do you wish to overwrite %s (y or n)? ",
 			ofname);
 			fflush(stderr);
-			read(2, response, 2);
+			if (read(2, response, 2) < 1) {
+			  perror("stderr"); break;
+			}
 			while (response[1] != '\n') {
 			    if (read(2, response+1, 1) < 0) {	/* Ack! */
 				perror("stderr"); break;
